@@ -1,7 +1,7 @@
 import requests
 import json
 import time
-import sys
+import platform
 
 
 class Query(object):
@@ -12,10 +12,11 @@ class Query(object):
 
     _BASE_URL = 'https://data.thinknum.com'
 
-    def __init__(self, client_id, client_secret, proxies={}):
+    def __init__(self, client_id, client_secret, proxies={}, verify=True):
         self._client_id = client_id
         self._client_secret = client_secret
         self._proxies = proxies
+        self._verify = verify
 
         self._token = None
         self._authenticate()
@@ -23,7 +24,7 @@ class Query(object):
             "Accept": "application/json",
             "Authorization": "token {token}".format(token=self._token),
             "X-API-Version": "20151130",
-            "User-Agent": "Python API/1.1"
+            "User-Agent": "Python API 1.75 / {local_version}".format(local_version=platform.python_version())
         }
 
         self._dataset_id = None
@@ -45,7 +46,8 @@ class Query(object):
             data=data,
             json=json,
             params=params,
-            proxies=self._proxies
+            proxies=self._proxies,
+            verify=self._verify
         )
 
     def _authenticate(self):
